@@ -14,6 +14,7 @@ __all__ = (
     'DecimalFieldTests',
     'DateFieldTests',
     'ListFieldTests',
+    'FragmentFieldTests',
 )
 
 class RecordOne(fixedwidth.Record):
@@ -24,6 +25,11 @@ class RecordTwo(RecordOne):
     field_three = fields.DecimalField(length=9)
     field_four = fields.DateField(length=2)
 
+class RecordThree(fixedwidth.Record):
+    frag = fields.FragmentField(record=RecordOne)
+    other_field = fields.StringField(length=3, default="BBB")
+
+
 class PaddingTests(TestCase):
 
     def test_str_padding_pads_right_with_spaces(self):
@@ -313,6 +319,55 @@ class DateFieldTests(TestCase):
         c = TestRecord()
         self.assertEqual(date(2000, 1, 1), c.field_one)
 
+
+class FragmentFieldTests(TestCase):
+
+    def test_to_python_returns_record_instance_when_none_given(self):
+        f = fields.FragmentField(record=RecordOne)
+        python_val = f.to_python(None)
+        self.assertIsInstance(python_val, RecordOne)
+
+    def test_to_python_returns_record_instance_when_given_string(self):
+        f = fields.FragmentField(record=RecordOne)
+        python_val = f.to_python('AAAAA1111111')
+        self.assertIsInstance(python_val, RecordOne)
+
+    def test_to_python_returns_record_instance_when_given_instance(self):
+        record = RecordOne()
+        f = fields.FragmentField(record=RecordOne)
+        python_val = f.to_python(record)
+        self.assertIsInstance(python_val, RecordOne)
+
+    def test_to_python_raises_type_error_when_receives_bad_input(self):
+        f = fields.FragmentField(record=RecordOne)
+        with self.assertRaises(TypeError) as ctx:
+            f.to_python(222)
+        self.assertEqual("Redefined field must be a string or RecordOne instance.", ctx.exception.message)
+
+    def test_to_record_returns_string_of_record_when_explicitly_set(self):
+        r = RecordThree(other_field="ZZZ")
+        self.assertEqual("AA   0000000ZZZ", r.to_record())
+
+    def test_to_record_returns_string_of_record_when_has_explicit_values(self):
+        my_record = RecordOne(field_one="aa", field_two=999)
+        r = RecordThree(frag=my_record, other_field="ZZZ")
+        self.assertEqual("aa   0000999ZZZ", r.to_record())
+
+    def test_creates_record_object_properly_from_string(self):
+        r = RecordThree.from_record("aaaaa9999999ZZZ")
+        self.assertEqual("aaaaa", r.sub_field.field_one)
+        self.assertEqual(9999999, r.sub_field.field_two)
+        self.assertEqual("ZZZ", r.other_field)
+        self.assertIsInstance(r.sub_field, RecordOne)
+
+    def test_creates_record_object_properly_from_string(self):
+        r = RecordThree()
+        r.frag.field_one = "aaa"
+        r.frag.field_two = 999
+
+        self.assertEqual("aaa  0000999BBB", r.to_record())
+
+
 class ListFieldTests(TestCase):
 
     def test_to_python_returns_list_of_records(self):
